@@ -14,7 +14,7 @@ from pyob.exceptions import (
     InvalidTypeError,
     UnicityError,
 )
-from pyob.tools import is_ob
+from pyob.tools import convert_string_to_pascal_case, is_ob
 
 
 # ┌─────────────────────────────────────────────────────────────────────────────────────
@@ -39,14 +39,17 @@ class ObDunderMixin:
     # │ __REPR__
     # └─────────────────────────────────────────────────────────────────────────────────
 
-    def __repr__(self):
+    def __repr__(self, _str=None):
         """ Representation Method """
 
         # Initialize representation
         representation = self.label_singular
 
+        # Convert representation to Pascal case
+        representation = convert_string_to_pascal_case(representation)
+
         # Add angle brackets to representation
-        representation = f"<{representation}: {str(self)}>"
+        representation = f"<{representation}: {self.__str__(_str=_str)}>"
 
         # Return representation
         return representation
@@ -62,17 +65,17 @@ class ObDunderMixin:
         cls = self.__class__
 
         # ┌─────────────────────────────────────────────────────────────────────────────
-        # │ CLEAN VALUE
+        # │ PRE-SETTER
         # └─────────────────────────────────────────────────────────────────────────────
 
-        # Get clean methods
-        _clean = cls._clean or {}
+        # Get pre-setter methods
+        _pre = cls._pre or {}
 
-        # Check if name in clean methods
-        if name in _clean:
+        # Check if name in pre-setter methods
+        if name in _pre:
 
-            # Clean value
-            value = _clean[name](self, value)
+            # Apply pre-setter to value
+            value = _pre[name](self, value)
 
         # ┌─────────────────────────────────────────────────────────────────────────────
         # │ ENFORCE KEY
@@ -126,12 +129,9 @@ class ObDunderMixin:
                 # Handle TypeError
                 except TypeError:
 
-                    # Get singular label
-                    label_singular = cls.label_singular
-
                     # Raise InvalidTypeError
                     raise InvalidTypeError(
-                        f"{label_singular}.{name} expects a value of type "
+                        f"{cls.__name__}.{name} expects a value of type "
                         f"{expected_type} but got: {value} ({type(value)})"
                     )
 
@@ -229,16 +229,34 @@ class ObDunderMixin:
                 and (other := _obs_by_unique_value[_value]) != self
             ):
 
-                # Get singular label
-                label_singular = cls.label_singular
-
                 # Raise UnicityError
                 raise UnicityError(
-                    f"A {label_singular} with a(n) {_field} of {_value} "
+                    f"A {cls.label_singular} with a(n) {_field} of {_value} "
                     f"already exists: {other}"
                 )
 
-            #
+            # ┌─────────────────────────────────────────────────────────────────────────
+            # │ RE-INDEX FIELD VALUE
+            # └─────────────────────────────────────────────────────────────────────────
+
+            if (
+                is_unique_together and all([f in self.__dict__ for f in _field])
+            ) or _field in self.__dict__:
+
+                # Get previous value
+                _value_previous = (
+                    tuple(self.__dict__[f] for f in _field)
+                    if is_unique_together
+                    else self.__dict__[_field]
+                )
+
+                # Check previous value is indexed
+                if _value_previous in _obs_by_unique_value:
+
+                    # Pop previous value from index
+                    _obs_by_unique_value.pop(_value_previous)
+
+            # Index new field value
             _obs_by_unique_value[_value] = self
 
             """
@@ -255,21 +273,34 @@ class ObDunderMixin:
         # │ RETURN PARENT SET ATTR
         # └─────────────────────────────────────────────────────────────────────────────
 
-        # Return parent set attr method
-        return super().__setattr__(name, value)
+        # Call parent set attr method
+        super().__setattr__(name, value)
+
+        # ┌─────────────────────────────────────────────────────────────────────────────
+        # │ POST-SETTER
+        # └─────────────────────────────────────────────────────────────────────────────
+
+        # Get post-setter methods
+        _post = cls._post or {}
+
+        # Check if name in post-setter methods
+        if name in _post:
+
+            # Apply post-setter to value
+            value = _post[name](self, value)
 
     # ┌─────────────────────────────────────────────────────────────────────────────────
     # │ __STR__
     # └─────────────────────────────────────────────────────────────────────────────────
 
-    def __str__(self, root=None):
+    def __str__(self, root=None, _str=None):
         """ String Method """
 
         # Initialize root
         root = root if root is not None else self
 
         # Get string field if defined otherwise the first key if any
-        string_field = self._str or (self._keys[0] if self._keys else None)
+        string_field = _str or self._str or (self._keys[0] if self._keys else None)
 
         # Set string to value of string field
         string = string_field and getattr(self, string_field, None)
