@@ -9,7 +9,7 @@ from operator import itemgetter
 # │ PROJECT IMPORTS
 # └─────────────────────────────────────────────────────────────────────────────────────
 
-from pyob.exceptions import MultipleObjectsError, ZeroObjectsError
+from pyob.exceptions import MultipleObjectsError, NonExistentKeyError, ZeroObjectsError
 from pyob.tools import (
     convert_obs_dict_to_list,
     filter_and,
@@ -42,22 +42,6 @@ class ObSetMethodMixin:
         # Update current instance
         self.__dict__ = (self + ob).__dict__
 
-    # ┌─────────────────────────────────────────────────────────────────────────────────
-    # │ CLEAR
-    # └─────────────────────────────────────────────────────────────────────────────────
-
-    def clear(self):
-        """ Clears a PyOb object set so that it is empty """
-
-        # Set objects to empty dict
-        self._obs = {}
-
-        # Set objects by key to empty dict
-        self._obs_by_key = {}
-
-        # Set objects by unique field to empty dict
-        self._obs_by_unique_field = {}
-
     # ┌─────────────────────────────────────────────────────────────────────────────────
     # │ COPY
     # └─────────────────────────────────────────────────────────────────────────────────
@@ -210,8 +194,13 @@ class ObSetMethodMixin:
         # Check if default is Nothing
         if default is Nothing:
 
-            # Raise KeyError
-            raise KeyError(key)
+            # Get object label singular
+            ob_label_singular = self.ob_label_singular
+
+            # Raise NonExistentKeyError
+            raise NonExistentKeyError(
+                f"A {ob_label_singular} instance with a key of {key} does not exist"
+            )
 
         # Return default
         return default
