@@ -2,7 +2,11 @@
 # │ PROJECT IMPORTS
 # └─────────────────────────────────────────────────────────────────────────────────────
 
-from pyob.tools.convert_ import convert_obs_dict_to_list
+from pyob.tools.convert_ import convert_obs_dict_to_list, convert_string_to_pascal_case
 from pyob.tools.filter_ import filter_and, filter_by_key, filter_by_keys, filter_or
+from pyob.tools.increment_ import increment_store
 from pyob.tools.is_ import is_iterable, is_ob, is_ob_set
+from pyob.tools.localize_ import localize
+from pyob.tools.remove_ import remove_duplicates
 from pyob.tools.split_ import split_camel_case
+from pyob.tools.traverse_ import traverse_pyob_bases
